==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/SplineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineSeriesBaseDescriptionMetadata } from "./SplineSeriesBaseDescriptionMetadata";
import { SplineSeriesDescription } from "./SplineSeriesDescription";
/**
 * @hidden
 */
var SplineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SplineSeriesDescriptionMetadata, _super);
    function SplineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SplineSeriesDescriptionMetadata.b = function (a) {
        if (SplineSeriesDescriptionMetadata.a == null) {
            SplineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SplineSeriesDescriptionMetadata.c(SplineSeriesDescriptionMetadata.a);
        }
        if (a.j(SplineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(SplineSeriesDescriptionMetadata.a);
    };
    SplineSeriesDescriptionMetadata.c = function (a) {
        SplineSeriesBaseDescriptionMetadata.c(a);
    };
    SplineSeriesDescriptionMetadata.d = function (a) {
        SplineSeriesDescriptionMetadata.b(a);
        a.aa("SplineSeries", function () { return new SplineSeriesDescription(); });
        a.z("SplineSeries", SplineSeriesDescriptionMetadata.a);
    };
    SplineSeriesDescriptionMetadata.$t = markType(SplineSeriesDescriptionMetadata, 'SplineSeriesDescriptionMetadata');
    SplineSeriesDescriptionMetadata.a = null;
    return SplineSeriesDescriptionMetadata;
}(Base));
export { SplineSeriesDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/SplineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineSeriesBaseDescriptionMetadata } from "./SplineSeriesBaseDescriptionMetadata";
import { SplineSeriesDescription } from "./SplineSeriesDescription";
/**
 * @hidden
 */
var SplineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SplineSeriesDescriptionMetadata, _super);
    function SplineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SplineSeriesDescriptionMetadata.b = function (a) {
        if (SplineSeriesDescriptionMetadata.a == null) {
            SplineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SplineSeriesDescriptionMetadata.c(SplineSeriesDescriptionMetadata.a);
        }
        if (a.k(SplineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.aa(SplineSeriesDescriptionMetadata.a);
    };
    SplineSeriesDescriptionMetadata.c = function (a) {
        SplineSeriesBaseDescriptionMetadata.c(a);
    };
    SplineSeriesDescriptionMetadata.d = function (a) {
        SplineSeriesDescriptionMetadata.b(a);
        a.ac("SplineSeries", function () { return new SplineSeriesDescription(); });
        a.ab("SplineSeries", SplineSeriesDescriptionMetadata.a);
    };
    SplineSeriesDescriptionMetadata.$t = markType(SplineSeriesDescriptionMetadata, 'SplineSeriesDescriptionMetadata');
    SplineSeriesDescriptionMetadata.a = null;
    return SplineSeriesDescriptionMetadata;
}(Base));
export { SplineSeriesDescriptionMetadata };
